about summary refs log tree commit diff
path: root/pkgs/applications/office/gnucash/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/applications/office/gnucash/default.nix')
-rw-r--r--pkgs/applications/office/gnucash/default.nix8
1 files changed, 4 insertions, 4 deletions
diff --git a/pkgs/applications/office/gnucash/default.nix b/pkgs/applications/office/gnucash/default.nix
index da94f9674ca28..1551f2cad4287 100644
--- a/pkgs/applications/office/gnucash/default.nix
+++ b/pkgs/applications/office/gnucash/default.nix
@@ -23,7 +23,7 @@
 , pkg-config
 , swig
 , webkitgtk
-, wrapGAppsHook
+, wrapGAppsHook3
 }:
 
 stdenv.mkDerivation rec {
@@ -40,7 +40,7 @@ stdenv.mkDerivation rec {
     cmake
     gettext
     makeWrapper
-    wrapGAppsHook
+    wrapGAppsHook3
     pkg-config
   ];
 
@@ -117,11 +117,11 @@ stdenv.mkDerivation rec {
     )
   '';
 
   # wrapGAppsHook would wrap all binaries including the cli utils which need
   # Perl wrapping
   dontWrapGApps = true;
 
   # gnucash is wrapped using the args constructed for wrapGAppsHook.
   # gnc-fq-* are cli utils written in Perl hence the extra wrapping
   postFixup = ''
     wrapProgram $out/bin/gnucash "''${gappsWrapperArgs[@]}"
@@ -117,11 +117,11 @@ stdenv.mkDerivation rec {
   '';
 
-  # wrapGAppsHook would wrap all binaries including the cli utils which need
+  # wrapGAppsHook3 would wrap all binaries including the cli utils which need
   # Perl wrapping
   dontWrapGApps = true;
@@ -117,11 +117,11 @@ stdenv.mkDerivation rec {
   dontWrapGApps = true;
 
-  # gnucash is wrapped using the args constructed for wrapGAppsHook.
+  # gnucash is wrapped using the args constructed for wrapGAppsHook3.
   # gnc-fq-* are cli utils written in Perl hence the extra wrapping
   postFixup = ''